# discordinfo

discordinfo is a Python Package build around Discord Accounts. 

discordinfo provides a simple way to scrape data from Discord accounts using Account Tokens. 

# Usage

Just use the following query inside your local terminal to see the uses and details for all commands inside discordinfo.

```
discordinfo
```
